@@ -236,8 +236,11 @@ get_client_id(const GNOME_Pilot_Client cb)
 }
 
 
+
+/********************************************************************************/
+
 static void
-pause_device(GPilotDevice *device,gpointer data)
+gpilotd_corba_pause_device(GPilotDevice *device,gpointer data)
 {
 	if (device->io) {
 		g_source_remove(device->in_handle);
@@ -245,22 +248,39 @@ pause_device(GPilotDevice *device,gpointer data)
 	}
 }
 
-/********************************************************************************/
+static void
+gpilotd_corba_pause_notify_monitor (gchar* key,
+				    GSList **value,
+				    CORBA_boolean *on_off) 
+{	
+	GNOME_Pilot_Client cb = CORBA_ORB_string_to_object(orb, (CORBA_char*)key, &ev);
+	GNOME_Pilot_Client_pause (cb, *on_off, &ev);
+
+	if (ev._major != CORBA_NO_EXCEPTION) {
+		char *client_id = get_client_id (cb);
+		g_message ("corba: monitor %.20s dead", client_id);
+		CORBA_exception_free (&ev);
+		CORBA_free (client_id);
+	}	
+}
 
 static void
 gpilotd_corba_pause(GNOME_Pilot_Daemon obj,
 		    CORBA_boolean on_off,
 		    CORBA_Environment *ev)  
 {
-	g_message("corba: gpilotd_corba_pause(%s)",on_off==TRUE?"true":"false");
 	if (orb_context->gpilotd_context->paused == on_off) return;
 
 	orb_context->gpilotd_context->paused = on_off;
 
+	g_hash_table_foreach (orb_context->monitors,
+			      (GHFunc)gpilotd_corba_pause_notify_monitor,
+			      &on_off);
+
 	if (orb_context->gpilotd_context->paused) {
 		g_list_foreach(orb_context->gpilotd_context->devices,
-			      (GFunc)pause_device,
-			       NULL);
+			      (GFunc)gpilotd_corba_pause_device,
+			       NULL);				      
 	} else {
 		kill(getpid(),SIGHUP);
 	}
@@ -268,6 +288,8 @@ gpilotd_corba_pause(GNOME_Pilot_Daemon obj,
 	return;
 }
 
+/********************************************************************************/
+
 static void
 gpilotd_corba_noop (GNOME_Pilot_Daemon obj,
 		    CORBA_Environment *ev)
@@ -275,6 +297,8 @@ gpilotd_corba_noop (GNOME_Pilot_Daemon obj,
 	return;
 }
 
+/********************************************************************************/
+
 static CORBA_unsigned_long
 gpilotd_corba_request_install(GNOME_Pilot_Daemon obj,
 			      const GNOME_Pilot_Client cb,
@@ -360,17 +384,17 @@ gpilotd_corba_request_restore(GNOME_Pilot_Daemon obj,
 		g_free(directory);
 		gpthrow_with_settings(UnknownPilot,0,exn,exn->pilotId = CORBA_string_dup(pilot_name));
 	}
-	if(stat(directory,&statbuf)==-1) {
-		g_free(client_id);
-		g_free(directory);
+	if (stat (directory, &statbuf)==-1) {
+		g_free (client_id);
+		g_free (directory);
 
-		gpthrow(MissingFile,0);
+		gpthrow (MissingFile,0);
 	}
-	if(S_ISDIR(statbuf.st_mode) && access(directory,R_OK)!=0) {
-		g_free(client_id);
-		g_free(directory);
-		g_message("or here access=%d, S_ISDIR=%d",access(directory,R_OK),S_ISDIR(statbuf.st_mode));
-		gpthrow(MissingFile,0);
+	if (S_ISDIR (statbuf.st_mode) && access (directory,R_OK)!=0) {
+		g_free (client_id);
+		g_free (directory);
+		g_message ("or here access=%d, S_ISDIR=%d", access(directory,R_OK), S_ISDIR(statbuf.st_mode));
+		gpthrow (MissingFile, 0);
 	}
 	req.timeout = survival==GNOME_Pilot_PERSISTENT?0:timeout;
 	req.cradle = NULL;
