@@ -1,3 +1,25 @@
+/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*- *//* 
+ * Copyright (C) 1998-2000 Free Software Foundation
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; either version 2 of the
+ * License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public
+ * License along with this program; if not, write to the
+ * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
+ *
+ * Authors: Eskil Heyn Olsen
+ *
+ */
+
 #ifndef __GPILOTD_QUEUE_IO__
 #define __GPILOTD_QUEUE_IO__
 
@@ -22,10 +44,10 @@ typedef enum {
   GREQ_INSTALL,
   GREQ_RESTORE,
   GREQ_CONDUIT,
-  GREQ_GET_SYSINFO,
 
   /* these are stored as [</dev/bla>-<sequence>] */
   GREQ_CRADLE_EVENT,
+  GREQ_GET_SYSINFO,
   GREQ_GET_USERINFO,
   GREQ_SET_USERINFO,
   GREQ_NEW_USERINFO,
@@ -85,6 +107,14 @@ GList* gpc_queue_load_requests_for_cradle(gchar *cradle);
 /* store a request in .gnome/gnome-pilot.d/queues/PILOT_ID */
 guint gpc_queue_store_request(GPilotRequest req);
 
+/* Here's some specific stores... */
+guint gpc_queue_store_set_userinfo_request (guint timeout, 
+					    const gchar *cradle, 
+					    const gchar *client_id,
+					    const gchar *username,
+					    guint userid,
+					    gboolean continue_sync);
+
 /* mark a request as processed, and purge from the queue files.
    This call also frees the data associated with the request.
  */
